# kakuyomu CLI

Command line interface for kakuyomu.jp writers.

## install

`pip install kakuyomu-cli`

`kakuyomu --help`

```
Usage: kakuyomu [OPTIONS] COMMAND [ARGS]...

  Kakuyomu CLI

  Command line interface for kakuyomu.jp

Options:
  --help  Show this message and exit.

Commands:
  episodes  List episodes titles
  login     Login
  logout    Logout
  status    Show login status
  works     List work titles
```
